@@ -253,8 +253,8 @@ sub _contains {
     }
   }
 
-  # search index may be 0 and blocks are not equal (see above), return undef (false)
-  return if $idx == 0;
+  # search index may be <=0 and blocks are not equal (see above), return undef (false)
+  return if $idx <= 0;
 
   # child before idx may contain the item
   return $node->{childs}[ $idx - 1 ]{block} if $node->{childs}[ $idx - 1 ]{block}->contains($block);
@@ -281,8 +281,8 @@ sub _contains_not_equal {
   # find first index where child->{block} >= block
   my $idx = List::MoreUtils::lower_bound { $_->{block}->cmp($block) } @{ $node->{childs} };
 
-  # search index may be 0 and equal not allowed, return undef (false)
-  return if $idx == 0;
+  # search index may be <=0 and equal not allowed, return undef (false)
+  return if $idx <= 0;
 
   # child before idx may contain the item
   return $node->{childs}[ $idx - 1 ]{block} if $node->{childs}[ $idx - 1 ]{block}->contains($block);
@@ -357,8 +357,8 @@ sub _lookup_not_equal {
   # find first index where child->{block} >= block
   my $idx = List::MoreUtils::lower_bound { $_->{block}->cmp($block) } @{ $node->{childs} };
 
-  # search index may be 0 and equal not allowed
-  return if $idx == 0;
+  # search index may be <= 0 and equal not allowed
+  return if $idx <= 0;
 
   # make alias, better to read or debug
   my $this = $node->{childs}[ $idx - 1 ];
